==> locomotive_booking_plugin-1.0.0.gem: lib/locomotive/booking/plugin/put_bookings_tag.rb <==
require 'locomotive_plugins'
require 'json'
require 'uri'

require_relative 'booking_document'
require_relative 'helper'

module Locomotive
    module Booking
        # Tag that changes existing bookings or creates them anew if they don't
        # exist yet.
        class PutBookingsTag < ::Liquid::Tag
            BOOKING_DATA_KEY        = "booking_data"
            BOOKING_YEAR_KEY        = "year"
            BOOKING_WEEK_KEY        = "week"
            BOOKING_WEEKDATA_KEY    = "weekData"
            SUCCESS_KEY             = "success"

            def initialize(tag_name, markup, tokens, context)
                @booking_data = nil

                markup.scan(::Liquid::TagAttributes) do |key, value|
                    ## Apparently you should remove possible quotes from the value.
                    value_minus_quotes = Helper.strip_quotes_from_value(value)

                    if key == BOOKING_DATA_KEY
                        @booking_data = value_minus_quotes
                    end
                end
                super
            end

            # The render method returns a JSON object that denotes either
            # success or failure of saving the given booking data.
            def render(context)
                success_json = { SUCCESS_KEY => true }.to_json
                failure_json = { SUCCESS_KEY => false }.to_json

                booking_data            = @booking_data
                evaluated_booking_data  = context[booking_data]
                booking_data            = evaluated_booking_data unless evaluated_booking_data.nil? or evaluated_booking_data.empty?

                begin
                    booking_data_json_string = URI.unescape(booking_data)
                    booking_data_hash = JSON.parse(booking_data_json_string)
                rescue JSON::ParserError
                    return failure_json
                end

                if booking_data_hash.nil?
                    return failure_json
                end

                year = booking_data_hash[BOOKING_YEAR_KEY]
                week = booking_data_hash[BOOKING_WEEK_KEY]
                weekData = booking_data_hash[BOOKING_WEEKDATA_KEY]

                if year.nil? or week.nil? or weekData.nil?
                    return failure_json
                end

                ## Check if there is already an entry for the given year and week.
                found_booking_data = BookingDocument::Availability.where(year: year, week: week).first
                if not found_booking_data
                    ## Need to create a new entry.
                    found_booking_data = BookingDocument::Availability.new
                    found_booking_data.year = year
                    found_booking_data.week = week
                end

                ## Regardless of whether the booking data already exists or
                ## not, the weekData must always be updated.
                found_booking_data.weekData = weekData
                found_booking_data.save

                success_json
            end

            def render_disabled(context)
                nil.to_json
            end
        end
    end
end

==> locomotive_booking_plugin-1.0.2.gem: lib/locomotive/booking/plugin/put_bookings_tag.rb <==
require 'locomotive_plugins'
require 'json'
require 'uri'

require_relative 'booking_document'
require_relative 'helper'

module Locomotive
    module Booking
        # Tag that changes existing bookings or creates them anew if they don't
        # exist yet.
        class PutBookingsTag < ::Liquid::Tag
            BOOKING_DATA_KEY        = "booking_data"
            BOOKING_YEAR_KEY        = "year"
            BOOKING_WEEK_KEY        = "week"
            BOOKING_WEEKDATA_KEY    = "weekData"
            SUCCESS_KEY             = "success"

            def initialize(tag_name, markup, tokens, context)
                @booking_data = nil

                markup.scan(::Liquid::TagAttributes) do |key, value|
                    ## Apparently you should remove possible quotes from the value.
                    value_minus_quotes = ::Helper.strip_quotes_from_value(value)

                    if key == BOOKING_DATA_KEY
                        @booking_data = value_minus_quotes
                    end
                end
                super
            end

            # The render method returns a JSON object that denotes either
            # success or failure of saving the given booking data.
            def render(context)
                success_json = { SUCCESS_KEY => true }.to_json
                failure_json = { SUCCESS_KEY => false }.to_json

                booking_data            = @booking_data
                evaluated_booking_data  = context[booking_data]
                booking_data            = evaluated_booking_data unless evaluated_booking_data.nil? or evaluated_booking_data.empty?

                begin
                    booking_data_json_string = URI.unescape(booking_data)
                    booking_data_hash = JSON.parse(booking_data_json_string)
                rescue JSON::ParserError
                    return failure_json
                end

                if booking_data_hash.nil?
                    return failure_json
                end

                year = booking_data_hash[BOOKING_YEAR_KEY]
                week = booking_data_hash[BOOKING_WEEK_KEY]
                weekData = booking_data_hash[BOOKING_WEEKDATA_KEY]

                if year.nil? or week.nil? or weekData.nil?
                    return failure_json
                end

                ## Check if there is already an entry for the given year and week.
                found_booking_data = BookingDocument::Availability.where(year: year, week: week).first
                if not found_booking_data
                    ## Need to create a new entry.
                    found_booking_data = BookingDocument::Availability.new
                    found_booking_data.year = year
                    found_booking_data.week = week
                end

                ## Regardless of whether the booking data already exists or
                ## not, the weekData must always be updated.
                found_booking_data.weekData = weekData
                found_booking_data.save

                success_json
            end

            def render_disabled(context)
                nil.to_json
            end
        end
    end
end
